"""
Import Wordpress posts from an XML file into django-vellum

To generate the XML file, login to the Wordpress Dashboard. Navigate to
    Tools -> Export
and select "Posts" rather than "All content".

Props to:
    http://blog.sejo.be/2010/02/14/import-wordpress-django-mingus/
"""
from optparse import make_option
from datetime import datetime
import xml.etree.ElementTree as ET

from django.core.management.base import BaseCommand, CommandError
from django.contrib.sites.models import Site
from django.contrib.comments.models import Comment
from django.contrib.contenttypes.models import ContentType
from django.template.defaultfilters import slugify

from vellum.models import Post, Category


class Command(BaseCommand):
    help = 'Imports Wordpress posts from an XML file into django-vellum'
    args = 'filename.xml'

    option_list = BaseCommand.option_list + (
        make_option('--excerpt',
                    action='store_true',
                    dest='excerpt',
                    default=False,
                    help="""Automagically search the post body for the
                         <!--more--> quicktag and place anything preceeding the
                         tag into the post's tease field."""),
    )

    def handle(self, *args, **options):
        try:
            file = args[0]
        except IndexError:
            raise CommandError('No file was specified')

        try:
            tree = ET.parse(file)
        except IOError:
            raise CommandError("%s could not be found" % file)

        wp = 'http://wordpress.org/export/1.1/'

        for item in tree.findall('channel/item'):
            # Get the post's slug
            slug = item.find('{%s}post_name' % wp).text

            # Unpublished posts will not have anything in their name tag (which
            # is used to hold the slug), so we have to create the slug from the
            # title.
            if slug is None:
                slug = slugify(item.find('title').text)

            print 'Importing post "%s"...' % slug

            # If the post is already in the database, get it. Otherwise create
            # it.
            try:
                post = Post.objects.get(slug=slug)
            except:
                post = Post()
                post.title = item.find('title').text
                post.slug = slug
                post.body = item.find('{http://purl.org/rss/1.0/modules/content/}encoded').text
                post.created = item.find('{%s}post_date' % wp).text

                # If the post was published, set its status to public.
                # Otherwise make it a draft.
                if item.find('{%s}status' % wp).text == 'publish':
                    post.status = 2
                else:
                    post.status = 1
                    # Unpublished posts will not have a timestamp associated
                    # with them. We'll set the creation date to now.
                    post.created = datetime.now()

                # Set publish time to the creation time.
                post.publish = post.created

                # If the excerpt flag was set, do some auto excerpting magic.
                if options['excerpt']:
                    # Partition the string at the Wordpress more quicktag.
                    partition = post.body.partition('<!--more-->')

                    # If the `more` tag was not found, Python will have
                    # returned a tuple with the full post body in the first
                    # item followed by two empty items. To make sure that the
                    # excerpt is only set if the post does actually contain a
                    # `morie` quicktag, we'll check to see if the third tuple
                    # item is an empty string.
                    if partition[2]:
                        post.tease = partition[0]

                # Post must be saved before we apply tags or comments.
                post.save()

            # Get all tags and categories. They look like this, respectively:
            # <category domain="post_tag" nicename="a tag">a tag</category>
            # <category domain="category" nicename="general">general</category>
            descriptors = item.findall('category')
            categories = []
            for descriptor in descriptors:
                if descriptor.attrib['domain'] == 'post_tag':
                    # Add the tag to the post
                    post.tags.add(descriptor.text)
                if descriptor.attrib['domain'] == 'category':
                    category = descriptor.text
                    # If the category exists, add it to the model. Otherwise,
                    # create the category, then add it.
                    try:
                        cat = Category.objects.get(slug=slugify(category))
                    except:
                        cat = Category(title=category, slug=slugify(category))
                        cat.save()
                    post.categories.add(cat)

            # Save the post again, this time with tags and categories.
            post.save()

            # Get and save the comments.
            comments = item.findall('{%s}comment' % (wp))
            for comment in comments:
                # When I was importing my posts, I stumbled upon a comment that
                # somehow had no author email associated with it. If that is
                # the case, don't bother importing the comment.
                email = comment.find('{%s}comment_author_email' % (wp)).text
                if email is None:
                    continue

                c = Comment()
                c.user_name = comment.find('{%s}comment_author' % wp).text
                c.user_email = comment.find('{%s}comment_author_email'
                                            % wp).text
                c.comment = comment.find('{%s}comment_content' % wp).text
                c.submit_date = comment.find('{%s}comment_date' % wp).text
                c.content_type = ContentType.objects.get(app_label='blog',
                                                         model='post')
                c.object_pk = post.id
                c.site_id = Site.objects.get_current().id

                # Only attempt to assign a user URL to the new comment if the
                # old comment has one.
                user_url = comment.find('{%s}comment_author_url' % wp).text
                if user_url:
                    c.user_url = user_url

                c.save()



import re

from django import template

from vellum.models import Post

register = template.Library()


class PostArchive(template.Node):
    def __init__(self, var_name):
        self.var_name = var_name

    def render(self, context):
        dates = Post.objects.published().dates('publish', 'month',
                                               order='DESC')
        if dates:
            context[self.var_name] = dates
        return ''


@register.tag
def get_post_archive(parser, token):
    try:
        tag_name, arg = token.contents.split(None, 1)
    except ValueError:
        raise template.TemplateSyntaxError("%s tag requires arguments"
                                           % token.contents.split()[0])
    m = re.search(r'as (\w+)', arg)
    if not m:
        raise template.TemplateSyntaxError("%s tag had invalid arguments"
                                           % tag_name)
    var_name = m.groups()[0]
    return PostArchive(var_name)



import re

from django import template
from django.conf import settings
from django.db import models

Post = models.get_model('vellum', 'post')
Category = models.get_model('vellum', 'category')
BlogRoll = models.get_model('vellum', 'blogroll')

register = template.Library()


class LatestPosts(template.Node):
    def __init__(self, limit, var_name):
        self.limit = int(limit)
        self.var_name = var_name

    def render(self, context):
        posts = Post.objects.published()[:self.limit]
        if posts and (self.limit == 1):
            context[self.var_name] = posts[0]
        else:
            context[self.var_name] = posts
        return ''


@register.tag
def get_latest_posts(parser, token):
    """
    Gets any number of latest posts and stores them in a varable.

    Syntax::

        {% get_latest_posts [limit] as [var_name] %}

    Example usage::

        {% get_latest_posts 10 as latest_post_list %}
    """
    try:
        tag_name, arg = token.contents.split(None, 1)
    except ValueError:
        raise template.TemplateSyntaxError("%s tag requires arguments"
                                           % token.contents.split()[0])
    m = re.search(r'(.*?) as (\w+)', arg)
    if not m:
        raise template.TemplateSyntaxError("%s tag had invalid arguments"
                                           % tag_name)
    format_string, var_name = m.groups()
    return LatestPosts(format_string, var_name)


class BlogCategories(template.Node):
    def __init__(self, var_name):
        self.var_name = var_name

    def render(self, context):
        categories = Category.objects.all()
        context[self.var_name] = categories
        return ''


@register.tag
def get_blog_categories(parser, token):
    """
    Gets all blog categories.

    Syntax::

        {% get_blog_categories as [var_name] %}

    Example usage::

        {% get_blog_categories as category_list %}
    """
    try:
        tag_name, arg = token.contents.split(None, 1)
    except ValueError:
        raise template.TemplateSyntaxError("%s tag requires arguments"
                                           % token.contents.split()[0])
    m = re.search(r'as (\w+)', arg)
    if not m:
        raise template.TemplateSyntaxError("%s tag had invalid arguments"
                                           % tag_name)
    var_name = m.groups()[0]
    return BlogCategories(var_name)


@register.filter
def get_links(value):
    """
    Extracts links from a ``Post`` body and returns a list.

    Template Syntax::

        {{ post.body|markdown:"safe"|get_links }}

    """
    try:
        try:
            from BeautifulSoup import BeautifulSoup
        except ImportError:
            from beautifulsoup import BeautifulSoup
        soup = BeautifulSoup(value)
        return soup.findAll('a')
    except ImportError:
        if settings.DEBUG:
            raise template.TemplateSyntaxError("Error in 'get_links' filter: "
                                               "BeautifulSoup isn't installed.")
    return value


class BlogRolls(template.Node):
    def __init__(self, var_name):
        self.var_name = var_name

    def render(self, context):
        blogrolls = BlogRoll.objects.all()
        context[self.var_name] = blogrolls
        return ''


@register.tag
def get_blogroll(parser, token):
    """
    Gets all blogroll links.

    Syntax::

        {% get_blogroll as [var_name] %}

    Example usage::

        {% get_blogroll as blogroll_list %}
    """
    try:
        tag_name, arg = token.contents.split(None, 1)
    except ValueError:
        raise template.TemplateSyntaxError("%s tag requires arguments"
                                           % token.contents.split()[0])
    m = re.search(r'as (\w+)', arg)
    if not m:
        raise template.TemplateSyntaxError("%s tag had invalid arguments"
                                           % tag_name)
    var_name = m.groups()[0]
    return BlogRolls(var_name)



"""
>>> from django.test import Client
>>> from vellum.models import Post, Category
>>> import datetime
>>> from django.core.urlresolvers import reverse
>>> client = Client()

>>> category = Category(title='Django', slug='django')
>>> category.save()
>>> category2 = Category(title='Rails', slug='rails')
>>> category2.save()

>>> post = Post(title='DJ Ango', slug='dj-ango', body='Yo DJ! Turn that music up!', status=2, publish=datetime.datetime(2008,5,5,16,20))
>>> post.save()

>>> post2 = Post(title='Where my grails at?', slug='where', body='I Can haz Holy plez?', status=2, publish=datetime.datetime(2008,4,2,11,11))
>>> post2.save()

>>> post.categories.add(category)
>>> post2.categories.add(category2)

>>> response = client.get(reverse('blog_index'))
>>> response.context[0]['object_list']
[<Post: DJ Ango>, <Post: Where my grails at?>]
>>> response.status_code
200

>>> response = client.get(reverse('blog_category_list'))
>>> response.context[0]['object_list']
[<Category: Django>, <Category: Rails>]
>>> response.status_code
200

>>> response = client.get(category.get_absolute_url())
>>> response.context[0]['object_list']
[<Post: DJ Ango>]
>>> response.status_code
200

>>> response = client.get(post.get_absolute_url())
>>> response.context[0]['object']
<Post: DJ Ango>
>>> response.status_code
200

>>> response = client.get(reverse('blog_search'), {'q': 'DJ'})
>>> response.context[0]['object_list']
[<Post: DJ Ango>]
>>> response.status_code
200
>>> response = client.get(reverse('blog_search'), {'q': 'Holy'})
>>> response.context[0]['object_list']
[<Post: Where my grails at?>]
>>> response.status_code
200
>>> response = client.get(reverse('blog_search'), {'q': ''})
>>> response.context[0]['message']
'Search term was too vague. Please try again.'

>>> response = client.get(reverse('blog_detail', args=[2008, 'apr', 2, 'where']))
>>> response.context[0]['object']
<Post: Where my grails at?>
>>> response.status_code
200
"""




from django.db.models import F
from django.http import Http404
from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from django.views.generic import (ListView, DetailView, ArchiveIndexView,
                                  DateDetailView, DayArchiveView,
                                  MonthArchiveView, YearArchiveView)

from simplesearch.functions import *
from taggit.models import Tag

from vellum.models import *
from vellum import settings as blog_settings


class PostIndexView(ArchiveIndexView):
    """Display all blog posts."""
    queryset = Post.objects.public()
    date_field = 'publish'
    paginate_by = blog_settings.BLOG_PAGESIZE
    template_name = 'vellum/post_list.html'


class PostArchiveView(ArchiveIndexView):
    """Display all blog posts on a single page."""
    queryset = Post.objects.public()
    date_field = 'publish'


class PostYearArchiveView(YearArchiveView):
    """Display all blog posts in a given year."""
    queryset = Post.objects.public()
    date_field = 'publish'
    paginate_by = blog_settings.BLOG_PAGESIZE
    make_object_list = True


class PostMonthArchiveView(MonthArchiveView):
    """Display all blog posts in a given month."""
    queryset = Post.objects.public()
    date_field = 'publish'
    paginate_by = blog_settings.BLOG_PAGESIZE

    def get_month_format(self):
        """
        Allow both 3-letter month abbreviations and month as a decimal number.
        """
        if len(self.get_month()) < 3:
            self.month_format = '%m'
        return self.month_format


class PostDayArchiveView(DayArchiveView):
    """Display all blog posts in a given day."""
    queryset = Post.objects.public()
    date_field = 'publish'
    paginate_by = blog_settings.BLOG_PAGESIZE

    def get_month_format(self):
        """
        Allow both 3-letter month abbreviations and month as a decimal number.
        """
        if len(self.get_month()) < 3:
            self.month_format = '%m'
        return self.month_format


class PostView(DateDetailView):
    """Display a blog post."""
    model = Post
    date_field = 'publish'

    def get_allow_future(self):
        """
        Allow super users to view posts with a publish date in the future.
        """
        if self.request.user.is_superuser:
            self.allow_future = True
        return self.allow_future

    def get_month_format(self):
        """
        Allow both 3-letter month abbreviations and month as a decimal number.
        """
        if len(self.get_month()) < 3:
            self.month_format = '%m'
        return self.month_format

    def get_object(self):
        # Call the superclass.
        object = super(PostView, self).get_object()
        # If the user isn't super and the post is not public, do not allow
        # viewing.
        if not self.request.user.is_superuser and object.status != 2:
            raise Http404
        # If the user's IP is not specified as internal, increase the post's
        # view count.
        if not self.request.META.get('REMOTE_ADDR') in blog_settings.BLOG_INTERNALIPS:
            object.visits = F('visits') + 1
            object.save()
        return object


class CategoryListView(ListView):
    """Display a list of categories."""
    model = Category


class CategoryDetailView(ListView):
    """Display all blog posts in a given category."""
    paginate_by = blog_settings.BLOG_PAGESIZE

    def category(self, **kwargs):
        return get_object_or_404(Category, slug=self.kwargs['slug'])

    def get_queryset(self, **kwargs):
        return Post.objects.published().filter(categories=self.category)

    def get_template_names(self, **kwargs):
        return 'vellum/category_detail.html'

    def get_context_data(self, **kwargs):
        # Call the base implementation first to get a context.
        context = super(CategoryDetailView, self).get_context_data(**kwargs)
        # Add the category to the context.
        context['category'] = self.category
        return context


class TagDetailView(ListView):
    """Display all blog posts with a given tag."""
    paginate_by = blog_settings.BLOG_PAGESIZE

    def tag(self, **kwargs):
        return get_object_or_404(Tag, slug=self.kwargs['slug'])

    def get_queryset(self, **kwargs):
        return Post.objects.published().filter(tags=self.tag)

    def get_template_names(self, **kwargs):
        return 'vellum/tag_detail.html'

    def get_context_data(self, **kwargs):
        # Call the base implementation first to get a context.
        context = super(TagDetailView, self).get_context_data(**kwargs)
        # Add in the tag to the context.
        context['tag'] = self.tag
        return context


def search(request, template_name='vellum/post_search.html',
           search_fields=['title', 'body', 'tags__name', 'categories__title']):
    """
    Search for blog posts.

    This template will allow you to setup a simple search form that will return
    results based on given search keywords.

    Template: ``vellum/post_search.html``
    Context:
        object_list
            List of blog posts that match given search term(s).
        search_term
            Given search term.
        message
            A message returned by the search.
    """
    context = {}
    message = ''
    query_string = ''

    if 'q' in request.GET:
        query_string = request.GET['q']
        entry_query = get_query(query_string, search_fields)

        try:
            results = Post.objects.published().filter(entry_query).distinct()
            if results:
                context = {'object_list': results, 'search_term': query_string}
            else:
                message = 'No results found! Please try a different search term.'
        except TypeError:
            message = 'Search term was too vague, please try again.'

        context['message'] = message

    return render_to_response(template_name, context,
                              context_instance=RequestContext(request))



from django.contrib import admin

from vellum.models import *
from vellum import settings


class CategoryAdmin(admin.ModelAdmin):
    prepopulated_fields = {'slug': ('title',)}
admin.site.register(Category, CategoryAdmin)


class PostAdmin(admin.ModelAdmin):
    display_fields = ['title', 'slug', 'author', 'markup', 'body', 'tease',
                      'status', 'allow_comments', 'publish', 'categories',
                      'tags', ]
    list_display = ('title', 'publish', 'status', 'visits')
    list_filter = ('publish', 'categories', 'status')
    search_fields = ('title', 'body')
    prepopulated_fields = {'slug': ('title',)}

    # If Django WMD is enabled, use the WMD-widgetized form.
    if settings.BLOG_WMD:
        try:
            from vellum.forms import PostForm
        except ImportError:
            pass
        else:
            form = PostForm
            # Remove the markup field from the display.
            display_fields.remove('markup')

    fieldsets = (
        (None, {
            'fields': display_fields
        }),
        ('Rendered markup', {
            'classes': ('collapse',),
            'fields': ('body_rendered', 'tease_rendered'),
        })
    )
admin.site.register(Post, PostAdmin)


class BlogRollAdmin(admin.ModelAdmin):
    list_display = ('name', 'url', 'sort_order',)
    list_editable = ('sort_order',)
admin.site.register(BlogRoll)



from vellum import settings


def blog_settings(request):
    """
    Add blog settings to the context, making them available to templates.
    """
    return {
        'BLOG_NAME': settings.BLOG_NAME,
        'BLOG_DESCRIPTION': settings.BLOG_DESCRIPTION,
        'BLOG_EXCERPTLENGTH': settings.BLOG_EXCERPTLENGTH,
        'BLOG_USEDISQUS': settings.BLOG_USEDISQUS,
    }



from django.db import models
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext_lazy as _
from django.db.models import permalink
from django.contrib.auth.models import User
from django.template.defaultfilters import truncatewords_html
from django.utils.timezone import now

from taggit.managers import TaggableManager
from django_markup.fields import MarkupField
from django_markup.markup import formatter
from inlines.parser import inlines

from vellum.managers import PublicManager
from vellum import settings


class Category(models.Model):
    """Category model."""
    title = models.CharField(_('title'), max_length=100)
    slug = models.SlugField(_('slug'), unique=True)

    class Meta:
        verbose_name = _('category')
        verbose_name_plural = _('categories')
        ordering = ('title',)

    def __unicode__(self):
        return u'%s' % self.title

    @permalink
    def get_absolute_url(self):
        return ('vellum_category_detail', None, {'slug': self.slug})


class Post(models.Model):
    """Post model."""
    STATUS_CHOICES = (
        (1, _('Draft')),
        (2, _('Public')),
    )
    title = models.CharField(_('title'), max_length=200)
    slug = models.SlugField(_('slug'), unique_for_date='publish',
                            max_length=100)
    author = models.ForeignKey(User, blank=True, null=True)
    markup = MarkupField(default='markdown')
    body = models.TextField(_('body'), )
    body_rendered = models.TextField(editable=True, blank=True, null=True)
    tease = models.TextField(_('tease'), blank=True)
    tease_rendered = models.TextField(editable=True, blank=True, null=True)
    visits = models.IntegerField(_('visits'), default=0, editable=False)
    status = models.IntegerField(_('status'), choices=STATUS_CHOICES,
                                 default=2)
    allow_comments = models.BooleanField(_('allow comments'), default=True)
    publish = models.DateTimeField(_('publish'), default=now())
    created = models.DateTimeField(_('created'), auto_now_add=True)
    modified = models.DateTimeField(_('modified'), auto_now=True)
    categories = models.ManyToManyField(Category, blank=True)
    tags = TaggableManager(blank=True)
    objects = PublicManager()

    class Meta:
        verbose_name = _('post')
        verbose_name_plural = _('posts')
        ordering = ('-publish',)
        get_latest_by = 'publish'

    def __unicode__(self):
        return u'%s' % self.title

    def save(self, *args, **kwargs):
        # Inlines must be rendered before markup in order to properly preserve
        # whitespace
        self.body_rendered = inlines(self.body)
        self.tease_rendered = inlines(self.tease)
        # Render the markup and save it in the body_rendered field.
        self.body_rendered = mark_safe(formatter(self.body_rendered,
                                                 filter_name=self.markup))
        self.tease_rendered = mark_safe(formatter(self.tease_rendered,
                                                  filter_name=self.markup))
        # Run the body and tease through Smartypants, if enabled.
        if settings.BLOG_SMARTYPANTS:
            self.body_rendered = mark_safe(formatter(self.body_rendered,
                                                     filter_name='smartypants'))
            self.tease_rendered = mark_safe(formatter(self.tease_rendered,
                                                      filter_name='smartypants'))
        # Call the real save.
        super(Post, self).save(*args, **kwargs)

    @permalink
    def get_absolute_url(self):
        return ('vellum_detail', None, {
            'year': self.publish.year,
            'month': self.publish.strftime('%m'),
            'day': self.publish.day,
            'slug': self.slug
        })

    @property
    def excerpt(self):
        """Return a post excerpt."""
        if self.tease_rendered:
            return self.tease_rendered

        return truncatewords_html(self.body_rendered,
                                  settings.BLOG_EXCERPTLENGTH)

    def get_previous_post(self):
        return self.get_previous_by_publish(status__gte=2)

    def get_next_post(self):
        return self.get_next_by_publish(status__gte=2)


class BlogRoll(models.Model):
    """Other blogs you follow."""
    name = models.CharField(max_length=100)
    url = models.URLField(verify_exists=False)
    sort_order = models.PositiveIntegerField(default=0)
    description = models.TextField(max_length=500, blank=True)
    relationship = models.CharField(max_length=200, blank=True)

    class Meta:
        ordering = ('sort_order', 'name',)
        verbose_name = _('blog roll')
        verbose_name_plural = _('blog roll')

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        return self.url



"""
These blog settings should not be edited directly.
Instead, overwrite them in the main project's setting file.
"""
from django.conf import settings
from django.contrib.sites.models import Site

# The name of the blog.
# This defaults to the name of the site.
BLOG_NAME = getattr(settings, 'BLOG_NAME', Site.objects.get_current().name)

# A short description of what the blog is about.
BLOG_DESCRIPTION = getattr(settings, 'BLOG_DESCRIPTION', 'A basic Django blog')

# How many posts should appear on a single page.
BLOG_PAGESIZE = getattr(settings, 'BLOG_PAGESIZE', 12)

# How many posts should appear in the RSS feed.
# This defaults to the same value as BLOG_PAGESIZE above.
BLOG_FEEDSIZE = getattr(settings, 'BLOG_FEEDSIZE', BLOG_PAGESIZE)

# Specify how many words post excerpts should be truncated to. Defaults to 100.
BLOG_EXCERPTLENGTH = getattr(settings, 'BLOG_EXCERPTLENGTH', 100)

# If set to true, the Markdown WMD editor from Django WMD will be used on the
# body field of all posts.
BLOG_WMD = getattr(settings, 'BLOG_WMD', False)

# A tuple of IP addresses. If the request's remote address is set to one of
# the IP addresses in this tuple, the visit counter will not be increased when
# a post is visted.
# This defaults to settings.INTERNAL_IPS, and you most likely don't want to
# change it.
BLOG_INTERNALIPS = getattr(settings, 'BLOG_INTERNALIPS', settings.INTERNAL_IPS)

# If set to true, Disqus will be used for comments. The django-disqus package
# should be installed before enabling this option. Defaults to false.
BLOG_USEDISQUS = getattr(settings, 'BLOG_USEDISQUS', False)

# If set to true, posts will be put through John Gruber's SmartyPants filter
# for fancy quotes and dashes.
# By default, if the smartypants python package is installed, the filter will
# be enabled. Otherwise, the filter will be disabled by default.
try:
    import smartypants
    smartyimport = True
except ImportError:
    smartyimport = False
BLOG_SMARTYPANTS = getattr(settings, 'BLOG_SMARTYPANTS', smartyimport)



from django.contrib.syndication.views import FeedDoesNotExist
from django.core.exceptions import ObjectDoesNotExist
from django.contrib.sites.models import Site
from django.contrib.syndication.views import Feed
from django.contrib.contenttypes.models import ContentType
from django.contrib.comments.models import Comment
from django.core.urlresolvers import reverse
from django.template.loader import render_to_string

from vellum import settings
from vellum.models import Post, Category


class BlogPostsFeed(Feed):
    _site = Site.objects.get_current()
    title = _site.name
    description = settings.BLOG_DESCRIPTION

    def link(self):
        return reverse('vellum')

    def items(self):
        return Post.objects.published()[:settings.BLOG_FEEDSIZE]

    def item_description(self, item):
        return render_to_string('vellum/feed/item_description.html',
                                {'post': item})

    def item_pubdate(self, obj):
        return obj.publish


class BlogPostsByCategory(Feed):

    def get_object(self, request, slug):
        return Category.objects.get(slug__exact=slug)

    def title(self, obj):
        _site = Site.objects.get_current()
        return '%s: %s' % (_site.name, obj.title)

    def link(self, obj):
        if not obj:
            raise FeedDoesNotExist
        return obj.get_absolute_url()

    def description(self, obj):
        return "Posts recently categorized as %s" % obj.title

    def items(self, obj):
        return obj.post_set.published()[:settings.BLOG_FEEDSIZE]

    def item_description(self, item):
        return render_to_string('vellum/feed/item_description.html',
                                {'post': item})

    def item_pubdate(self, obj):
        return obj.publish


class CommentsFeed(Feed):
    _site = Site.objects.get_current()
    title = '%s comment feed' % _site.name
    description = '%s comments feed.' % _site.name

    def link(self):
        return reverse('vellum')

    def items(self):
        ctype = ContentType.objects.get_for_model(Post)
        return Comment.objects.filter(content_type=ctype)[:settings.BLOG_FEEDSIZE]

    def item_pubdate(self, obj):
        return obj.submit_date



from django.conf.urls.defaults import *
from django.views.generic import TemplateView

from vellum.feeds import BlogPostsFeed, BlogPostsByCategory
from vellum.views import *

urlpatterns = patterns('',
    url(r'^(?P<year>\d{4})/(?P<month>\d{2})/(?P<day>\d{1,2})/(?P<slug>[-\w]+)/$',
        view=PostView.as_view(),
        name='vellum_detail'
    ),
    url(r'^(?P<year>\d{4})/(?P<month>\d{2})/(?P<day>\d{1,2})/$',
        view=PostDayArchiveView.as_view(),
        name='vellum_archive_day'
    ),
    url(r'^(?P<year>\d{4})/(?P<month>\d{2})/$',
        view=PostMonthArchiveView.as_view(),
        name='vellum_archive_month'
    ),
    url(r'^(?P<year>\d{4})/$',
        view=PostYearArchiveView.as_view(),
        name='vellum_archive_year'
    ),
    url(r'^categories/(?P<slug>[-\w]+)/$',
        view=CategoryDetailView.as_view(),
        name='vellum_category_detail'
    ),
    url(r'^categories/$',
        view=CategoryListView.as_view(),
        name='vellum_category_list'
    ),
    url(r'^tags/(?P<slug>[-\w]+)/$',
        view=TagDetailView.as_view(),
        name='vellum_tag_detail'
    ),
    url(r'^tags/$',
        view=TemplateView.as_view(template_name='vellum/tag_list.html'),
        name='vellum_tag_list'
    ),
    url(r'^search/$',
        view=search,
        name='vellum_search'
    ),
    url(r'^archives/$',
        view=PostArchiveView.as_view(),
        name='vellum_archives'
    ),
    url(r'^feed/categories/(?P<slug>[^/]+)/$',
        view=BlogPostsByCategory(),
        name='vellum_feed_category'
    ),
    url(r'^feed/$',
        view=BlogPostsFeed(),
        name='vellum_feed_latest'
    ),
    url(r'^$',
        view=PostIndexView.as_view(),
        name='vellum'
    ),
)



from django.contrib.sitemaps import Sitemap

from vellum.models import Post


class BlogSitemap(Sitemap):
    changefreq = "never"
    priority = 0.5

    def items(self):
        return Post.objects.published()

    def lastmod(self, obj):
        return obj.publish



from django import forms

from vellum.models import Post

# Attempt to import WMDWidget from Django WMD.
# If it's around, create a form that uses the widget on the body field of a
# post.
try:
    from wmd.widgets import WMDWidget

    class PostForm(forms.ModelForm):
        body = forms.CharField(widget=WMDWidget(large=True))

        class Meta:
            model = Post
except ImportError:
    pass



from setuptools import setup, find_packages

setup(
    name='django-vellum',
    packages=find_packages(),
    version='1.2',
    description='A web log for Django.',
    author='Peter Hogg',
    author_email='peter@havenaut.net',
    url='https://github.com/pigmonkey/django-vellum',
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
    ],
    long_description=open('README.md').read(),
    include_package_data=True,
    zip_safe=False,
    install_requires=['django-inlineobjects',
                      'django-simplesearch',
                      'django-taggit',
                      'django-taggit-templatetags',
                      'django-markup',
                      'Markdown'],
)



from django.utils.timezone import now
from django.db.models import Manager


class PublicManager(Manager):

    def public(self):
        """Return public posts."""
        return self.get_query_set().filter(status__gte=2)

    def published(self):
        """Return public posts that are not in the future."""
        return self.get_query_set().filter(status__gte=2, publish__lte=now())
